<?php
/**
 * Back compatibility functions for WordPress versions prior to 4.7
 *
 * @package Forty_Two
 * @license GPL-2.0-or-later
 * @link    https://aspengrovestudios.com/themes/forty-two/
 */

/**
 * Prevents switching to the theme on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since 1.0.0
 */
function forty_two_switch_theme() {
	switch_theme( WP_DEFAULT_THEME );
	unset( $_GET['activated'] );

	add_action( 'admin_notices', 'forty_two_upgrade_notice' );
}
add_action( 'after_switch_theme', 'forty_two_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to the theme
 * on WordPress versions prior to 4.7.
 *
 * @since 1.0.0
 *
 * @global string $wp_version WordPress version.
 */
function forty_two_upgrade_notice() {
	/* translators: %s: WordPress version number */
	$message = sprintf( __( 'Forty Two requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'forty-two' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', esc_html( $message ) );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.7.
 *
 * @since 1.0.0
 *
 * @global string $wp_version WordPress version.
 */
function forty_two_customize() {
	/* translators: %s: WordPress version number */
	wp_die( esc_html( sprintf( __( 'Forty Two requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'forty-two' ), $GLOBALS['wp_version'] ) ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'forty_two_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.7.
 *
 * @since 1.0.0
 *
 * @global string $wp_version WordPress version.
 */
function forty_two_preview() {
	if ( isset( $_GET['preview'] ) ) {
		/* translators: %s: WordPress version number */
		wp_die( esc_html( sprintf( __( 'Forty Two requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'forty-two' ), $GLOBALS['wp_version'] ) ) );
	}
}
add_action( 'template_redirect', 'forty_two_preview' );
